==> cscec5b-wzxt-api-3.0.0-20210322.075525-171-sources.jar: com/ejianc/business/wzxt/vo/ExitGFVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 推送供方
 * 
 * @author syj
 * 
 */
public class ExitGFVO {
    private static final long serialVersionUID = 1L;

    private Long id;
    private java.lang.String billCode; // 单据编号
    private java.lang.String projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.String orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.String contractId; // 合同主键
    private java.lang.String contractName; // 合同名称
    private java.lang.String contractCode; // 合同编号
    private java.lang.String supplierId; // 设备供应商
    private java.lang.String supplierName; // 供应商名称
    private java.lang.String exitDate; // 退场日期
    private java.lang.String exitNote; // 退场说明
    private String sceneurl;//现场照片url（逗号隔开）例如：group1/M00/03/ED/rB7JfGBAizCAIVS_AAD6Jjikza4607.jpg
    private String czsignurl;//承租方签字url（逗号隔开）
    private String jlsingurl;//租赁房签字url（逗号隔开）
    private List<ExitDetailGFVO> exitDetail = new ArrayList<>(); // 退场单明细


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getExitDate() {
        return exitDate;
    }

    public void setExitDate(String exitDate) {
        this.exitDate = exitDate;
    }

    public String getExitNote() {
        return exitNote;
    }

    public void setExitNote(String exitNote) {
        this.exitNote = exitNote;
    }

    public List<ExitDetailGFVO> getExitDetail() {
        return exitDetail;
    }

    public void setExitDetail(List<ExitDetailGFVO> exitDetail) {
        this.exitDetail = exitDetail;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public String getCzsignurl() {
        return czsignurl;
    }

    public void setCzsignurl(String czsignurl) {
        this.czsignurl = czsignurl;
    }

    public String getJlsingurl() {
        return jlsingurl;
    }

    public void setJlsingurl(String jlsingurl) {
        this.jlsingurl = jlsingurl;
    }
}

==> cscec5b-wzxt-api-3.0.0-20210323.091033-178-sources.jar: com/ejianc/business/wzxt/vo/ExitGFVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 推送供方
 * 
 * @author syj
 * 
 */
public class ExitGFVO {
    private static final long serialVersionUID = 1L;

    private Long id;
    private Long applyId;//申请单主键
    private java.lang.String billCode; // 单据编号
    private java.lang.String projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.String orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.String contractId; // 合同主键
    private java.lang.String contractName; // 合同名称
    private java.lang.String contractCode; // 合同编号
    private java.lang.String supplierId; // 设备供应商
    private java.lang.String supplierName; // 供应商名称
    private java.lang.String exitDate; // 退场日期
    private java.lang.String exitNote; // 退场说明
    private String sceneurl;//现场照片url（逗号隔开）例如：group1/M00/03/ED/rB7JfGBAizCAIVS_AAD6Jjikza4607.jpg
    private String czsignurl;//承租方签字url（逗号隔开）
    private String jlsingurl;//租赁房签字url（逗号隔开）
    private List<ExitDetailGFVO> exitDetail = new ArrayList<>(); // 退场单明细


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getExitDate() {
        return exitDate;
    }

    public void setExitDate(String exitDate) {
        this.exitDate = exitDate;
    }

    public String getExitNote() {
        return exitNote;
    }

    public void setExitNote(String exitNote) {
        this.exitNote = exitNote;
    }

    public List<ExitDetailGFVO> getExitDetail() {
        return exitDetail;
    }

    public void setExitDetail(List<ExitDetailGFVO> exitDetail) {
        this.exitDetail = exitDetail;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public String getCzsignurl() {
        return czsignurl;
    }

    public void setCzsignurl(String czsignurl) {
        this.czsignurl = czsignurl;
    }

    public String getJlsingurl() {
        return jlsingurl;
    }

    public void setJlsingurl(String jlsingurl) {
        this.jlsingurl = jlsingurl;
    }
}
